#include "TROOT.h"
/**
 * \brief Run as root -l test_gui_v5.cpp+ or
 *               root -l test_gui.cpp+(1) or
 * 				 root -l "test_gui_v5.cpp+(\"F500file-00001.bin\",8192,2000)" or
 * 				 root -l "test_gui_v5.cpp+(\"Z:/Measurements/160926 CLYC Detektor S2AA0486 KS n+Cs137/01 Pulserecord 980V S2AA0486 - check/F500file-00001.bin\",8192,2000)"
 * \note Tested with ROOT v5.34 on Windows and Linux
 * \note Call before source /opt/root/bin/thisroot.sh
 * \note Some GUI bugs with TGComboBox and TGHSlider are just corrected in ROOT6 v6.08 
 * \see https://root.cern.ch/phpBB3/viewtopic.php?f=3&t=22554 https://sft.its.cern.ch/jira/browse/ROOT-8406
 * \note This is a workaround (alias) for running the original test_gui.cpp+ with ROOT v5
 */

/**
 * \brief Function to open file stream with given binary format through GUI
 * \param fileName the name of the raw file to analyze
 * \param samplesPerPulse number of samples per pulse
 * \param preTrigger Position of trigger point, in sample points. For baseline calculation
 * \param overflow Overflow bin
 * \param bytesPerSample 2 bytes (int16) are used per sample point. Other things are not supported
 * \param subtractBaseline automatic baseline subtraction
 * \param persist set 2D persistency accumulation
 * \param xmin zoom min x value
 * \param xmax zoom max x value
 * \param ymin zoom min y value
 * \param ymax zoom max y value
 */		
void test_gui_v5(const TString fileName, const UShort_t samplesPerPulse, const UShort_t preTrigger, const Short_t overflow=32767, const UShort_t bytesPerSample=2, const Bool_t subtractBaseline=kTRUE, const Bool_t persist=kFALSE, const Int_t xmin=0, const Int_t xmax=8192, const Int_t ymin=0, const Int_t ymax=16000)
{
	gROOT->ProcessLine(".L PulseSurfer.cpp+");
	gROOT->ProcessLine((TString)".x test_gui.cpp+(\""+fileName+"\","+to_string(samplesPerPulse)+","+to_string(preTrigger)+","+to_string(overflow)+","+to_string(bytesPerSample)+","+to_string(subtractBaseline)+","+to_string(persist)+","+to_string(xmin)+","+to_string(xmax)+","+to_string(ymin)+","+to_string(ymax)+")");
}

/**
 * \brief Function to test the GUI
 * \param id some id parameter
 */
void test_gui_v5(const Int_t id = -1)
{
	gROOT->ProcessLine(".L PulseSurfer.cpp+");
	gROOT->ProcessLine((TString)".x test_gui.cpp+("+to_string(id)+")");
}
